@@ -13,20 +13,20 @@ class HasSource(object):
 
     """
 
-    def __init__(self, source):
+    def __init__(self, source: PerformedSource):
         self._source = None
         self.source = source
 
     @property
-    def source(self):
+    def source(self) -> PerformedSource:
         """Get the list of parameters."""
         return self._source
 
     @source.setter
-    def source(self, value):
+    def source(self, value: PerformedSource):
         if value is None:
             self._source = None
         elif isinstance(value, PerformedSource):
             self._source = value
         else:
-            raise TypeError("Source must be a PerformedSource; was {}".format(type(value)))
+            raise TypeError(f"Source must be a PerformedSource; was {type(value)}")
