@@ -22,14 +22,21 @@ class InChI(MolecularValue):
 
     @property
     def inchi(self) -> str:
-        """Get the formula as a string."""
+        """Get the InChI as a string."""
         return self._inchi
 
     @inchi.setter
     def inchi(self, value: str):
+        """Set the InChI, correcting for some minor variations in format."""
         if value is None:
             self._inchi = None
         elif isinstance(value, str):
+            if value.lower().startswith('1s/'):
+                value = value.replace(value[:2], 'InChI=1S')
+            elif not value.lower().startswith('inchi'):
+                value = f"InChI=1S/{value}"
+            elif not value.startswith('InChI'):
+                value = value.replace(value[:5], 'InChI')
             self._inchi = value
         else:
             raise TypeError("InChI must be given as a string; got {}".format(type(value)))
